@@ -504,16 +504,16 @@ class OneOf(object):
     """ Validator which succeeds if the value passed to it is one of
     a fixed set of values """
 
-    def __init__(self, choices):
+    _MSG_ERR = _('"${val}" is not one of ${choices}')
+
+    def __init__(self, choices, msg_err=_MSG_ERR):
+        self.msg_err = msg_err
         self.choices = choices
 
     def __call__(self, node, value):
         if value not in self.choices:
             choices = ', '.join(['%s' % x for x in self.choices])
-            err = _(
-                '"${val}" is not one of ${choices}',
-                mapping={'val': value, 'choices': choices},
-            )
+            err = _(self.msg_err, mapping={'val': value, 'choices': choices})
             raise Invalid(node, err)
 
 
@@ -1055,7 +1055,7 @@ class Set(SchemaType):
 class List(SchemaType):
     """ Type representing an ordered sequence of items.
 
-    Desrializes an iterable to a ``list`` object.
+    Deserializes an iterable to a ``list`` object.
 
     If the :attr:`colander.null` value is passed to the serialize
     method of this class, the :attr:`colander.null` value will be
@@ -1709,7 +1709,7 @@ class GlobalObject(SchemaType):
                 value = self.package.__name__
             else:
                 value = self.package.__name__ + value
-        return pkg_resources.EntryPoint.parse('x=%s' % value).load(False)
+        return pkg_resources.EntryPoint.parse('x=%s' % value).resolve()
 
     def _zope_dottedname_style(self, node, value):
         """ package.module.attr style """
@@ -1882,7 +1882,7 @@ class DateTime(SchemaType):
                 result = iso8601.parse_date(
                     cstruct, default_timezone=self.default_tzinfo
                 )
-        except (ValueError, iso8601.ParseError) as e:
+        except (ValueError, TypeError, iso8601.ParseError) as e:
             raise Invalid(
                 node, _(self.err_template, mapping={'val': cstruct, 'err': e})
             )
@@ -1960,7 +1960,7 @@ class Date(SchemaType):
             else:
                 result = iso8601.parse_date(cstruct)
             result = result.date()
-        except iso8601.ParseError as e:
+        except (ValueError, TypeError, iso8601.ParseError) as e:
             raise Invalid(
                 node, _(self.err_template, mapping={'val': cstruct, 'err': e})
             )
